indexing
	description: "Extension of C_DATE from Eiffel Software"
	license: "Eiffel Forum License v2 - See license.txt"
	source: "{
		Amalasoft Corporation
		273 Harwood Avenue
		Littleton, MA 01460 USA
		}"
	status: "Copyright 1995-2008, Amalasoft"
	date: "$Date: 2008/12/03 $"
	revision: "$Revision: 001$"

class AEL_UNIX_DATE

inherit
	C_DATE
		redefine
			out
		end

create
	default_create, make_utc, make_from_timet, make_from_timet_utc

--|========================================================================
feature {NONE} -- Creation
--|========================================================================

	make_from_timet (v: NATURAL_32) is
		do
			default_create
			update_from_timet (v)
		end

	make_from_timet_utc (v: NATURAL_32) is
		do
			make_utc
			update_from_timet (v)
		end

	--|--------------------------------------------------------------

	update_from_timet (t: NATURAL_32) is
			-- Set time/date to given time_t value
		local
			l_tm, l_time: POINTER
		do
			l_time := l_time.memory_alloc (time_t_structure_size)
			set_time_t (l_time, t)
			if is_utc then
				l_tm := gmtime ($t)
			else
				l_tm := localtime ($t)
			end
			internal_item.item.memory_copy (l_tm, tm_structure_size)
			l_time.memory_free
		end

--|========================================================================
feature -- External representation
--|========================================================================

	out: STRING is
		local
			d: DATE
			t: TIME
			dt: DATE_TIME
		do
			create d.make (year_now, month_now, day_now)
			create t.make_fine (
				hour_now, minute_now, second_now + millisecond_now / 1000)
			create dt.make_by_date_time (d, t)
			Result := dt.formatted_out (Ks_udate_fmt)
		end

--|========================================================================
feature {NONE} -- Constants
--|========================================================================

	Ks_udate_fmt: STRING is "[0]mm/[0]dd/yyyy hh12:[0]mi:[0]ss AM";

--|========================================================================
feature -- UTC Externals; callable anonymously
--|========================================================================

	set_time_t (a_time: POINTER; t: NATURAL_32) is
		external
			"C inline use <time.h>"
		alias
			"*((time_t *) $a_time) = (time_t) $t;"
		end

	--|--------------------------------------------------------------

	current_utc: NATURAL_32 is
			-- Current GMT time in UTC form (seconds since epoch)
		external
			"C inline use <time.h>"
		alias
			"[
				return time (NULL);
			]"
		end

end -- class AEL_UNIX_DATE
